<?php

if (!function_exists('optionsframework_init')) {
    define('OPTIONS_FRAMEWORK_DIRECTORY', esc_url(get_template_directory_uri() . '/inc/'));
    require(get_template_directory() . '/inc/options-framework.php');
}

function indigos_register_menus()
{
    register_nav_menu( 'menu-1', 'Menu 1' );
}

add_action('init', 'indigos_register_menus');

if (!function_exists('indigos_of_register_js')) :
    function indigos_of_register_js()
    {
        wp_enqueue_script('screen', esc_url(get_template_directory_uri() . '/js/screen.js'), array('jquery'), '1.0', true);
        wp_enqueue_script('jquery.prettyPhoto', esc_url(get_template_directory_uri() . '/js/jquery.prettyPhoto.js'), array('jquery'), '1.0', true);
        wp_enqueue_script('superfish', esc_url(get_template_directory_uri() . '/js/superfish.js'), array('jquery'), '1.0', true);
        wp_enqueue_script('flexslider', esc_url(get_template_directory_uri() . '/js/jquery.flexslider.js'), array('jquery'), '1.0', true);
        wp_enqueue_script('jquery.prettyPhoto', esc_url(get_template_directory_uri() . '/js/jquery.prettyPhoto.js'), array('jquery'), '1.0', true);
        wp_enqueue_script('support', esc_url(get_template_directory_uri() . '/js/support.js'), array('jquery'), '1.0', true);
        wp_enqueue_style('base', get_stylesheet_directory_uri() . '/css/base.css');
        wp_enqueue_style('skeleton', get_stylesheet_directory_uri() . '/css/skeleton.css');
        wp_enqueue_style('prettyPhoto', get_stylesheet_directory_uri() . '/css/prettyPhoto.css');
        wp_enqueue_style('flexslider', get_stylesheet_directory_uri() . '/css/flexslider.css');
        if (is_singular() && comments_open() && get_option('thread_comments')) {
            wp_enqueue_script('comment-reply');
        }
    }
endif;

add_action('wp_enqueue_scripts', 'indigos_of_register_js');

function indigos_wp_title($title, $sep)
{
    global $paged, $page;

    if (is_feed())
        return $title;

    // Add the site name.
    $title .= get_bloginfo('name', 'display');

    // Add the site description for the home/front page.
    $site_description = get_bloginfo('description', 'display');
    if ($site_description && (is_home() || is_front_page()))
        $title = "$title $sep $site_description";

    // Add a page number if necessary.
    if ($paged >= 2 || $page >= 2)
        $title = "$title $sep " . sprintf(__('Page %s', 'indigos'), max($paged, $page));

    return $title;
}

add_filter('wp_title', 'indigos_wp_title', 10, 2);

function indigos_widgets_init()
{
    register_sidebar(array(
        'name' => __('Blog', 'indigos'),
        'id' => 'blog',
        'description' => __('Blog widget area', 'indigos'),
        'before_widget' => '<section class="widget">',
        'after_widget' => '</section>',
        'before_title' => '<h3 class="widget-title">',
        'after_title' => '</h3><div class="boxtwosep"></div>',
    ));

    register_sidebar(array(
        'name' => __('Contact', 'indigos'),
        'id' => 'contact',
        'description' => __('Contact widget area', 'indigos'),
        'before_widget' => '<section class="widget">',
        'after_widget' => '</section>',
        'before_title' => '<h3 class="widget-title">',
        'after_title' => '</h3><div class="boxtwosep"></div>',
    ));

    register_sidebar(array(
        'name' => __('Page', 'indigos'),
        'id' => 'page',
        'description' => __('Page widget area', 'indigos'),
        'before_widget' => '<section class="widget">',
        'after_widget' => '</section>',
        'before_title' => '<h3 class="widget-title">',
        'after_title' => '</h3><div class="boxtwosep"></div>',
    ));

    register_sidebar(array(
        'name' => __('Footer', 'indigos'),
        'id' => 'footer',
        'description' => __('Footer widget area', 'indigos'),
        'before_widget' => '<div class="one_fourth">',
        'after_widget' => '</div>',
        'before_title' => '<h3>',
        'after_title' => '</h3>',
    ));
}

add_theme_support('automatic-feed-links');

add_action('widgets_init', 'indigos_widgets_init');

add_theme_support('post-thumbnails');

add_image_size('post-img', 630, 300, true);

if ( ! function_exists( 'indigos_paginate_page' ) ) :
    function indigos_paginate_page() {
        wp_link_pages( array( 'before' => '<div class="pagination">', 'after' => '</div><div class="clear"></div>', 'link_before' => '<span class="current_pag">','link_after' => '</span>' ) );
    }
endif;


if (!isset($content_width)) $content_width = 900;

if (is_singular() && comments_open() && get_option('thread_comments')) {
    wp_enqueue_script('comment-reply');
}

add_action('indigos_display_credits', 'indigos_credits');

if (!function_exists('indigos_content_nav')) :
    function indigos_content_nav($html_id)
    {
        global $wp_query;

        $html_id = esc_attr($html_id);

        if ($wp_query->max_num_pages > 1) : ?>
            <nav id="<?php echo $html_id; ?>" class="navigation" role="navigation">
                <div
                    class="nav-previous"><?php next_posts_link(__('<span class="meta-nav">&larr;</span> Older posts', 'indigos')); ?></div>
                <div
                    class="nav-next"><?php previous_posts_link(__('Newer posts <span class="meta-nav">&rarr;</span>', 'indigos')); ?></div>
            </nav><!-- #<?php echo $html_id; ?> .navigation -->
        <?php endif;
    }
endif;

if (!function_exists('indigos_credits')) :
    function indigos_credits()
    {
        $text = '<p class="copyright">Theme created by <a href="' . esc_url('http://www.wpmodern.com/') . '">WPModern</a>. Powered by <a href="' . esc_url('http://wordpress.org/') . '">WordPress.org</a></p>';
        echo apply_filters('indigos_credits_text', $text);
    }
endif;

add_action('indigos_display_credits', 'indigos_credits');

?>

