<?php
/**
 * A unique identifier is defined to store the options in the database and reference them from the theme.
 * By default it uses the theme name, in lowercase and without spaces, but this can be changed if needed.
 * If the identifier changes, it'll appear as if the options have been reset.
 */

function optionsframework_option_name() {

    // This gets the theme name from the stylesheet
    $themename = wp_get_theme();
    $themename = preg_replace("/\W/", "_", strtolower($themename) );

    $optionsframework_settings = get_option( 'optionsframework' );
    $optionsframework_settings['id'] = $themename;
    update_option( 'optionsframework', $optionsframework_settings );
}

/**
 * Defines an array of options that will be used to generate the settings page and be saved in the database.
 * When creating the 'id' fields, make sure to use all lowercase and no spaces.
 *
 * If you are making your theme translatable, you should replace 'options_framework_theme'
 * with the actual text domain for your theme.  Read more:
 * http://codex.wordpress.org/Function_Reference/load_theme_textdomain
 */

function optionsframework_options() {


    // Pull all the categories into an array
    $options_categories = array();
    $options_categories_obj = get_categories();
    foreach ($options_categories_obj as $category) {
        $options_categories[$category->cat_ID] = $category->cat_name;
    }
    // Pull all tags into an array
    $options_tags = array();
    $options_tags_obj = get_tags();
    foreach ( $options_tags_obj as $tag ) {
        $options_tags[$tag->term_id] = $tag->name;
    }
    // Pull all the pages into an array
    $options_pages = array();
    $options_pages_obj = get_pages('sort_column=post_parent,menu_order');
    $options_pages[''] = 'Select a page:';
    foreach ($options_pages_obj as $page) {
        $options_pages[$page->ID] = $page->post_title;
    }
    // If using image radio buttons, define a directory path
    $imagepath =  get_template_directory_uri() . '/inc/images/';
    $set_year = date('Y');
    $options = array();

    /* General Settings */

    $options[] = array(
        'name' => __('General Settings', 'options_framework_theme'),
        'type' => 'heading');

    $options[] = array(
        'name' => __('Header Logo Image', 'options_framework_theme'),
        'desc' => __('', 'options_framework_theme'),
        'id' => 'logo_image',
        'type' => 'upload');

    $options[] = array(
        'name' => __('Footer copyright text left', 'options_framework_theme'),
        'desc' => __('', 'options_framework_theme'),
        'id' => 'footer_text_left',
        'type' => 'text');

    $options[] = array(
        'name' => __('Twitter Url', 'options_framework_theme'),
        'desc' => __('', 'options_framework_theme'),
        'id' => 'twitter',
        'type' => 'text');

    $options[] = array(
        'name' => __('Facebook Url', 'options_framework_theme'),
        'desc' => __('', 'options_framework_theme'),
        'id' => 'facebook',
        'type' => 'text');

    $options[] = array(
        'name' => __('Google Url', 'options_framework_theme'),
        'desc' => __('', 'options_framework_theme'),
        'id' => 'google',
        'type' => 'text');

    $options[] = array(
        'name' => __('Dribbble Url', 'options_framework_theme'),
        'desc' => __('', 'options_framework_theme'),
        'id' => 'dribbble',
        'type' => 'text');

    $options[] = array(
        'name' => __('Enter your custom CSS styles.', 'options_framework_theme'),
        'desc' => __('', 'options_framework_theme'),
        'id' => 'custom_css_styles',
        'std' => '',
        'type' => 'textarea');

    $options[] = array(
        'name' => __('Home Page', 'options_framework_theme'),
        'type' => 'heading');

    $options[] = array(
        'name' => __('Banner Image', 'options_framework_theme'),
        'desc' => __('Recommended image sizes 1920X412', 'options_framework_theme'),
        'id' => 'banner',
        'type' => 'upload');

    $options[] = array(
        'name' => __('Top Box 1 Image', 'options_framework_theme'),
        'desc' => __('Recommended image sizes 254X147', 'options_framework_theme'),
        'id' => 'top_box_1_image',
        'type' => 'upload');

    $options[] = array(
        'name' => __('Top Box 1 Title', 'options_framework_theme'),
        'desc' => __('', 'options_framework_theme'),
        'id' => 'top_box_1_title',
        'type' => 'text');

    $options[] = array(
        'name' => __('Top Box 1 Link', 'options_framework_theme'),
        'desc' => __('', 'options_framework_theme'),
        'id' => 'top_box_1_link',
        'type' => 'text');

    $options[] = array(
        'name' => __('Top Box 1 Content', 'options_framework_theme'),
        'desc' => __('', 'options_framework_theme'),
        'id' => 'top_box_1_content',
        'type' => 'textarea');

    $options[] = array(
        'name' => __('Top Box 2 Image', 'options_framework_theme'),
        'desc' => __('Recommended image sizes 270X180', 'options_framework_theme'),
        'id' => 'top_box_2_image',
        'type' => 'upload');

    $options[] = array(
        'name' => __('Top Box 2 Title', 'options_framework_theme'),
        'desc' => __('', 'options_framework_theme'),
        'id' => 'top_box_2_title',
        'type' => 'text');

    $options[] = array(
        'name' => __('Top Box 2 Link', 'options_framework_theme'),
        'desc' => __('', 'options_framework_theme'),
        'id' => 'top_box_2_link',
        'type' => 'text');

    $options[] = array(
        'name' => __('Top Box 2 Content', 'options_framework_theme'),
        'desc' => __('', 'options_framework_theme'),
        'id' => 'top_box_2_content',
        'type' => 'textarea');

    $options[] = array(
        'name' => __('Top Box 3 Image', 'options_framework_theme'),
        'desc' => __('Recommended image sizes 270X180', 'options_framework_theme'),
        'id' => 'top_box_3_image',
        'type' => 'upload');

    $options[] = array(
        'name' => __('Top Box 3 Title', 'options_framework_theme'),
        'desc' => __('', 'options_framework_theme'),
        'id' => 'top_box_3_title',
        'type' => 'text');

    $options[] = array(
        'name' => __('Top Box 3 Link', 'options_framework_theme'),
        'desc' => __('', 'options_framework_theme'),
        'id' => 'top_box_3_link',
        'type' => 'text');

    $options[] = array(
        'name' => __('Top Box 3 Content', 'options_framework_theme'),
        'desc' => __('', 'options_framework_theme'),
        'id' => 'top_box_3_content',
        'type' => 'textarea');

    return $options;
}